/*
	Actiona
	Copyright (C) 2005 Jonathan Mercier-Ganady

	Actiona is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Actiona is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, see <http://www.gnu.org/licenses/>.

	Contact : jmgr@jmgr.info
*/

#include "global.h"

#include <QSysInfo>

namespace Global
{
	QString currentOSType()
	{
#ifdef Q_OS_LINUX
		return "linux";
#endif
#ifdef Q_OS_WIN
		return "windows";
#endif

		return "unknown";
	}

    int currentOSBits()
    {
        if(QSysInfo::currentCpuArchitecture().contains("64"))
            return 64;

        return 32;
    }

    int applicationBits()
    {
        return QSysInfo::WordSize;
    }
}
